# Identity Channel Mixer

::: linax.channel_mixers.identity.IdentityChannelMixerConfig
    options:
      members:
        - build

---

::: linax.channel_mixers.identity.IdentityChannelMixer
    options:
      members:
        - __init__
        - __call__
